==> 1.17.1.tar.gz: lib/src/videos/helpers/video/video_helper.dart <==
part of modern_form_videos;

class ModernFormVideoHelper {
  static Future<void> shareVideoFromUrl(String url, String text) async {
    Uint8List? bytes = await download(url);
    if (bytes != null) {
      await shareVideo(bytes, text);
    }
  }

  static Future<void> shareVideo(Uint8List bytes, String text) async {
    await ModernFormVideoPlatformHelper.shareVideo(bytes, text);
  }

  static Future<Uint8List?> download(String url,
      [void Function(int?, int)? onBytesReceived]) {
    if (url.contains("youtube") || url.contains("youtu.be")) {
      return downloadFromYoutube(url, onBytesReceived);
    } else {
      return ModernFormDownloadHelper.downloadWithProgress(url,
          onBytesReceived: onBytesReceived);
    }
  }

  static Future<Uint8List?> downloadWithProgress(String url) async {
    if (url.contains("youtube") || url.contains("youtu.be")) {
      ModernFormProgressDialog progressDialog = ModernFormProgressDialog();
      var stream = BehaviorSubject<double>.seeded(0.0);
      var streamText =
          BehaviorSubject<String>.seeded('Fazendo download do arquivo...');
      progressDialog.showProgressDialog(
        streamValue: stream,
        streamText: streamText,
        progressColor: Colors.white,
        barrierColor: Color(0x88222222),
      );

      Uint8List? bytes = await downloadFromYoutube(
        url,
        (totalByteCount, bytesTransferred) {
          double percent = 0;
          percent = bytesTransferred / totalByteCount;

          stream.add(percent);
          streamText.add("${(percent * 100).toStringAsFixed(2)}% concluído...");
        },
        true,
      );
      stream.close();
      streamText.close();
      progressDialog.dismissProgressDialog();

      return bytes;
    } else {
      return ModernFormDownloadHelper.downloadWithProgress(url);
    }
  }

  static Future<Uint8List?> simpleDownload(String url) {
    return ModernFormDownloadHelper.simpleDownload(url);
  }

  static Future<Uint8List?> downloadFromYoutube(String url,
      [void Function(int, int)? onBytesReceived, bool? force]) async {
    return ModernFormVideoPlatformHelper.downloadFromYoutube(
        url, onBytesReceived, force);
  }
}

==> 1.20.0.tar.gz: lib/src/videos/helpers/video/video_helper.dart <==
part of modern_form_videos;

class ModernFormVideoHelper {
  static Future<void> shareVideoFromUrl(String url, String text) async {
    Uint8List? bytes = await download(url);
    if (bytes != null) {
      await shareVideo(bytes, text);
    }
  }

  static Future<void> shareVideo(Uint8List bytes, String text) async {
    await ModernFormVideoPlatformHelper.shareVideo(bytes, text);
  }

  static bool isYoutubeUrl(String url) =>
      url.contains("youtube") || url.contains("youtu.be");

  static Future<Uint8List?> download(String url,
      [void Function(int?, int)? onBytesReceived, bool? force]) {
    if (isYoutubeUrl(url)) {
      return downloadFromYoutube(url, onBytesReceived, force);
    } else {
      return ModernFormDownloadHelper.downloadWithProgress(url,
          onBytesReceived: onBytesReceived);
    }
  }

  static Future<Uint8List?> downloadWithProgress(String url) async {
    if (isYoutubeUrl(url)) {
      ModernFormProgressDialog progressDialog = ModernFormProgressDialog();
      var stream = BehaviorSubject<double>.seeded(0.0);
      var streamText =
          BehaviorSubject<String>.seeded('Fazendo download do arquivo...');
      progressDialog.showProgressDialog(
        streamValue: stream,
        streamText: streamText,
        progressColor: Colors.white,
        barrierColor: Color(0x88222222),
      );

      Uint8List? bytes = await downloadFromYoutube(
        url,
        (totalByteCount, bytesTransferred) {
          double percent = 0;
          percent = bytesTransferred / totalByteCount;

          stream.add(percent);
          streamText.add("${(percent * 100).toStringAsFixed(2)}% concluído...");
        },
        true,
      );
      stream.close();
      streamText.close();
      progressDialog.dismissProgressDialog();

      return bytes;
    } else {
      return ModernFormDownloadHelper.downloadWithProgress(url);
    }
  }

  static Future<Uint8List?> simpleDownload(String url) {
    return ModernFormDownloadHelper.simpleDownload(url);
  }

  static Future<Uint8List?> downloadFromYoutube(String url,
      [void Function(int, int)? onBytesReceived, bool? force]) async {
    return ModernFormVideoPlatformHelper.downloadFromYoutube(
        url, onBytesReceived, force);
  }

  static Future<int?> getYoutubeDownLoadLength(String url) =>
      ModernFormVideoPlatformHelper.getYoutubeDownLoadLength(url);

  static Future<int?> getDownLoadLength(String url) {
    if (isYoutubeUrl(url)) {
      return getYoutubeDownLoadLength(url);
    } else {
      return ModernFormDownloadHelper.getDownLoadLength(url);
    }
  }
}
